import { GrayArrowObject } from "./GrayArrowObject";
declare class WebStorage extends GrayArrowObject {
    constructor();
    get storageProvider(): Storage;
    /**
     * Clears all storage.
     */
    clear(): void;
    /**
     * Gets an item from the storageProvider.
     * @param key The key of the storageProvider item to retrieve.
     * @returns The value stored at key, an object if one is detected, otherwise null if the key cannot be found.
     */
    getItem<T extends object>(key: string): T | undefined;
    getString(key: string): string | null;
    /**
     * Removes a key item from storageProvider.
     * @param key The key of the storageProvider item to remove.
     */
    removeItem(key: string): void;
    /**
     * Sets a storageProvider item at key with value.
     * @param key The key of the storageProvider item to remove.
     * @param value The string or object to store into the sessonStorage key.
     */
    setItem(key: string, value: any): void;
}
/**
 * Override our WebStorage object's storageProvide for our specific use case.
 * We need to hold this in a method as Storage cannot be accessed until useEffect().
 */
declare class WebStorageLocal extends WebStorage {
    get storageProvider(): Storage;
}
/**
 * Override our WebStorage object's storageProvide for our specific use case.
 * We need to hold this in a method as Storage cannot be accessed until useEffect().
 */
declare class WebStorageSession extends WebStorage {
    get storageProvider(): Storage;
}
export declare const LocalStorage: WebStorageLocal;
export declare const SessionStorage: WebStorageSession;
export {};
