"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SessionStorage = exports.LocalStorage = void 0;
const exception_types_1 = require("./exception-types");
const GrayArrowObject_1 = require("./GrayArrowObject");
const skky_1 = require("./skky");
class WebStorage extends GrayArrowObject_1.GrayArrowObject {
    constructor() {
        super();
    }
    get storageProvider() {
        throw new exception_types_1.GrayArrowException('No storage provider', 'storageProvider');
    }
    /**
     * Clears all storage.
     */
    clear() {
        this.storageProvider.clear();
    }
    /**
     * Gets an item from the storageProvider.
     * @param key The key of the storageProvider item to retrieve.
     * @returns The value stored at key, an object if one is detected, otherwise null if the key cannot be found.
     */
    getItem(key) {
        const val = (0, skky_1.safestrTrim)(this.getString(key));
        if ((0, skky_1.hasData)(val)) {
            if ((val.startsWith('{') && val.endsWith('}'))
                || (val.startsWith('[') && val.endsWith(']'))) {
                return (0, skky_1.safestrToJson)(val);
            }
        }
    }
    getString(key) {
        return this.storageProvider.getItem(key);
    }
    /**
     * Removes a key item from storageProvider.
     * @param key The key of the storageProvider item to remove.
     */
    removeItem(key) {
        this.storageProvider.removeItem(key);
    }
    /**
     * Sets a storageProvider item at key with value.
     * @param key The key of the storageProvider item to remove.
     * @param value The string or object to store into the sessonStorage key.
     */
    setItem(key, value) {
        const saveval = ((0, skky_1.isObject)(value) || (0, skky_1.isArray)(value)) ? (0, skky_1.safeJsonToString)(value) : String(value);
        this.storageProvider.setItem(key, saveval);
    }
}
/**
 * Override our WebStorage object's storageProvide for our specific use case.
 * We need to hold this in a method as Storage cannot be accessed until useEffect().
 */
class WebStorageLocal extends WebStorage {
    get storageProvider() {
        return localStorage;
    }
}
/**
 * Override our WebStorage object's storageProvide for our specific use case.
 * We need to hold this in a method as Storage cannot be accessed until useEffect().
 */
class WebStorageSession extends WebStorage {
    get storageProvider() {
        return sessionStorage;
    }
}
exports.LocalStorage = new WebStorageLocal();
exports.SessionStorage = new WebStorageSession();
