export type ColorRange = readonly [string, string];
/**
 * Returns an HTML #FFFFFF color that is the percent between the start and end colors provided.
 * @param colorRange The starting and ending colors for the gradient scale in HTML #FFFFFF format (# optional).
 * @param percent The percentage of the gradient scale you want returned.
 * @returns An HTML #FFFFFF formatted color that is the middle color of the percent between the start and end colors.
 */
export declare function InterpolateColorRange(colorRange: ColorRange, percent: number): string;
/**
 * Returns an HTML #FFFFFF color range based on the colorRange and the weights provided.
 * Used to get the gradients used for Politiscales.
 * @param colorRange The starting and ending colors for the gradient scale in HTML #FFFFFF format (# optional).
 * @param startWeight The weight for calculating the starting color.
 * @param endWeight The weight for calculating the ending color.
 * @returns An HTML #FFFFFF formatted color that is the middle color of the percent between the start and end colors.
 */
export declare function InterpolateWeightedColorRange(colorRange: ColorRange, startWeight: number, endWeight: number): ColorRange;
