"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InstrumentationStatistics = void 0;
const exception_types_1 = require("./exception-types");
const GrayArrowObject_1 = require("./GrayArrowObject");
const skky_1 = require("./skky");
class InstrumentationStatistics extends GrayArrowObject_1.GrayArrowObject {
    constructor(totalProcessed, numSuccesses, numFailures) {
        super();
        this.successes = 0;
        this.failures = 0;
        this.totalProcessed = 0;
        this.skipped = 0;
        this.update = 0;
        this.upsert = 0;
        this.add = 0;
        this.delete = 0;
        this.msg = [];
        this.startTime = new Date();
        this.totalProcessed = (totalProcessed || 0);
        this.successes = (numSuccesses || 0);
        this.failures = (numFailures || 0);
    }
    get className() {
        return 'InstrumentationStatistics';
    }
    addStats(stats) {
        if ((0, skky_1.isObject)(stats)) {
            this.successes += (stats.successes || 0);
            this.failures += (stats.failures || 0);
            this.totalProcessed += (stats.totalProcessed || 0);
            this.skipped += (stats.skipped || 0);
            this.add += (stats.add || 0);
            this.delete += (stats.delete || 0);
            this.update += (stats.update || 0);
            this.upsert += (stats.upsert || 0);
            this.msg = this.msg.concat((0, skky_1.safeArray)(stats.msg));
        }
    }
    addMessage(msg) {
        const fname = 'addMessage';
        if ((0, skky_1.isArray)(msg)) {
            this.msg = this.msg.concat(msg);
            return this.msg.length;
        }
        else if ((0, skky_1.isObject)(msg)) {
            this.msg.push(JSON.stringify(msg));
            return this.msg.length;
        }
        else if ((0, skky_1.isString)(msg)) {
            this.msg.push(msg);
            return this.msg.length;
        }
        // else if (msg) {
        //   const s = String(msg)
        //   this.msg.push(s)
        // }
        // return 0
        throw new exception_types_1.GrayArrowException('Message is not a string or set of strings.', this.classMethodString(fname), '' + msg);
    }
    addFailure(msg) {
        ++this.failures;
        this.addProcessed(msg);
        return this.failures;
    }
    addSuccess(msg) {
        ++this.successes;
        this.addProcessed(msg);
        return this.successes;
    }
    addSkip(msg) {
        ++this.skipped;
        this.addProcessed(msg);
        return this.skipped;
    }
    added(msg) {
        ++this.add;
        this.addMessage(msg);
        return this.add;
    }
    deleted(msg) {
        ++this.delete;
        this.addMessage(msg);
        return this.delete;
    }
    updated(msg) {
        ++this.update;
        this.addMessage(msg);
        return this.update;
    }
    upserted(msg) {
        ++this.upsert;
        this.addMessage(msg);
        return this.upsert;
    }
    addProcessed(msg) {
        ++this.totalProcessed;
        if ((0, skky_1.hasData)(msg)) {
            this.addMessage(msg);
        }
        return this.totalProcessed;
    }
    finished() {
        this.finishTime = new Date();
    }
    get processingTime() {
        return (0, skky_1.timeDifference)(this.startTime, this.finishTime || new Date());
    }
    /** Gets the total processing time in seconds. */
    get processingTimeInSeconds() {
        return (0, skky_1.timeDifferenceInSeconds)(this.startTime, this.finishTime || new Date());
    }
    processingTimeString(longFormat) {
        return (0, skky_1.timeDifferenceString)(this.startTime, this.finishTime || new Date(), longFormat);
    }
    lineSeparator(isOneLine = false, multilineSeparator) {
        if (isOneLine) {
            return ', ';
        }
        return (0, skky_1.safestr)(multilineSeparator || '\n', '\n');
    }
    getNumberString(num) {
        return (0, skky_1.getNumberString)(num, 0);
    }
    messageString(isOneLine) {
        let s = `Processed ${this.getNumberString(this.totalProcessed)} items in ${this.processingTimeString(true)}${isOneLine ? '' : '.'}`;
        if (this.add) {
            s += `${this.lineSeparator(isOneLine)}Added: ${this.getNumberString(this.add)}${isOneLine ? '' : '.'}`;
        }
        if (this.update) {
            s += `${this.lineSeparator(isOneLine)}Updated: ${this.getNumberString(this.update)}${isOneLine ? '' : '.'}`;
        }
        if (this.upsert) {
            s += `${this.lineSeparator(isOneLine)}Upserted: ${this.getNumberString(this.upsert)}${isOneLine ? '' : '.'}`;
        }
        if (this.delete) {
            s += `${this.lineSeparator(isOneLine)}Deleted: ${this.getNumberString(this.delete)}${isOneLine ? '' : '.'}`;
        }
        if (this.skipped) {
            s += `${this.lineSeparator(isOneLine)}Skipped: ${this.getNumberString(this.skipped)}${isOneLine ? '' : '.'}`;
        }
        if (this.successes) {
            s += `${this.lineSeparator(isOneLine)}Successes: ${this.getNumberString(this.successes)}${isOneLine ? '' : '.'}`;
        }
        if (this.failures) {
            s += `${this.lineSeparator(isOneLine)}Failures: ${this.getNumberString(this.failures)}${isOneLine ? '' : '.'}`;
        }
        if (isOneLine) {
            s += '.';
        }
        else if (this.msg.length) {
            s += '\n\nMessages:';
            this.msg.forEach(m => {
                s += `\n${m}`;
            });
        }
        return s;
    }
}
exports.InstrumentationStatistics = InstrumentationStatistics;
