"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalStorage = void 0;
const skky_1 = require("./skky");
exports.LocalStorage = {
    /**
     * Clears all localStorage.
     */
    clear: function () {
        localStorage.clear();
    },
    /**
     * Gets an item from localStorage.
     * @param key The key of the localStorage item to retrieve.
     * @returns The value stored at key, an object if one is detected, otherwise null if the key cannot be found.
     */
    getItem(key) {
        const val = (0, skky_1.safestrTrim)(this.getString(key));
        if ((0, skky_1.hasData)(val)) {
            if ((val.startsWith('{') && val.endsWith('}'))
                || (val.startsWith('[') && val.endsWith(']'))) {
                return (0, skky_1.safestrToJson)(val);
            }
        }
    },
    getString(key) {
        return localStorage.getItem(key);
    },
    /**
     * Removes a key item from localStorage.
     * @param key The key of the localStorage item to remove.
     */
    removeItem: function (key) {
        localStorage.removeItem(key);
    },
    /**
     * Sets a localStorage item at key with value.
     * @param key The key of the localStorage item to remove.
     * @param value The string or object to store into the sessonStorage key. objects are converted to strings.
     */
    setItem(key, value) {
        const saveval = (0, skky_1.isObject)(value) ? (0, skky_1.safeJsonToString)(value) : String(value);
        localStorage.setItem(key, saveval);
    },
};
