"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SessionStorage = void 0;
const skky_1 = require("./skky");
exports.SessionStorage = {
    /**
     * Clears all sessionStorage.
     */
    clear: function () {
        sessionStorage.clear();
    },
    /**
     * Gets an item from sessionStorage.
     * @param key The key of the sessionStorage item to retrieve.
     * @returns The value stored at key, an object if one is detected, otherwise null if the key cannot be found.
     */
    getItem(key) {
        const val = (0, skky_1.safestrTrim)(this.getString(key));
        if ((0, skky_1.hasData)(val)) {
            if ((val.startsWith('{') && val.endsWith('}'))
                || (val.startsWith('[') && val.endsWith(']'))) {
                return (0, skky_1.safestrToJson)(val);
            }
        }
    },
    getString(key) {
        return sessionStorage.getItem(key);
    },
    /**
     * Removes a key item from sessionStorage.
     * @param key The key of the sessionStorage item to remove.
     */
    removeItem: function (key) {
        sessionStorage.removeItem(key);
    },
    /**
     * Sets a sessionStorage item at key with value.
     * @param key The key of the sessionStorage item to remove.
     * @param value The string or object to store into the sessonStorage key.
     */
    setItem(key, value) {
        const saveval = ((0, skky_1.isObject)(value) || (0, skky_1.isArray)(value)) ? (0, skky_1.safeJsonToString)(value) : String(value);
        sessionStorage.setItem(key, saveval);
    },
};
