import { IdName } from './id-name';
import { INameValue } from './name-value';
import { IDate, IName, IPrice, ISlug, IType, IVal, I_Id } from './interfaces';
export interface ISymbol {
    symbol: string;
}
export interface ITicker {
    ticker: string;
}
export interface IVolume<T = number> {
    volume: T;
}
export interface ISymbolName extends ISymbol, IName {
}
export interface ISymbolPrice extends ISymbol, IPrice {
}
export interface ISymbolPriceName extends ISymbolPrice, ISymbolName {
}
export interface ISymbolPriceVolume extends ISymbolPrice, IVolume {
}
export interface ISymbolSearch extends ISymbolName {
    currency: string;
    stockExchange: string;
    exchangeShortName: string;
}
export interface IAssetQuoteResponse extends ISymbolPriceVolume, ISymbolName {
    changesPercentage: number;
    change: number;
    dayLow: number;
    dayHigh: number;
    yearHigh: number;
    yearLow: number;
    marketCap: number;
    priceAvg50: number;
    priceAvg200: number;
    avgVolume: number;
    exchange: string;
    open: number;
    previousClose: number;
    eps: number;
    pe: number;
    earningsAnnouncement: string;
    sharesOutstanding: number;
    timestamp: number;
}
export type PolitiscaleName = 'climate' | 'freeSpeech' | 'religion';
export interface IPolitiscale extends INameValue<number, PolitiscaleName> {
}
export interface IHasPolitiscales {
    scales?: IPolitiscale[];
}
export interface ICompanyCity extends IDate, IHasPolitiscales, IName, ISlug, ITicker {
    description: string;
    imageUrl: string;
    website: string;
}
export interface IUsersWithCount<Tid = string> extends I_Id<Tid> {
    email: string;
    firstname: string;
    lastname: string;
    status: number;
    updated: Date;
    created: Date;
    lastlogin?: Date;
    count: number;
}
export interface ICompanyUsersWithCount extends IName {
    total: number;
    numusers: number;
    status: number;
    imageuri: string;
    imageurihref: string;
    email: string;
    created: Date;
}
export interface ILoginWithCount {
    email: string;
    ip: string;
    created: Date;
    logoutTime: Date;
}
export interface IExchangeInfo extends ISymbolPriceName {
    exchange: string;
    exchangeShortName: string;
}
export interface ICompanyExecutive extends ISymbolName {
    yearBorn: number;
    pay: number;
    currencyPay: string;
    title: string;
    gender: string;
    titleSince: string;
}
export interface ICompanyFinancialRatios {
    dividendYielTTM: number;
    dividendYielPercentageTTM: number;
    peRatioTTM: number;
    pegRatioTTM: number;
    payoutRatioTTM: number;
    currentRatioTTM: number;
    quickRatioTTM: number;
    cashRatioTTM: number;
    daysOfSalesOutstandingTTM: number;
    daysOfInventoryOutstandingTTM: number;
    operatingCycleTTM: number;
    daysOfPayablesOutstandingTTM: number;
    cashConversionCycleTTM: number;
    grossProfitMarginTTM: number;
    operatingProfitMarginTTM: number;
    pretaxProfitMarginTTM: number;
    netProfitMarginTTM: number;
    effectiveTaxRateTTM: number;
    returnOnAssetsTTM: number;
    returnOnEquityTTM: number;
    returnOnCapitalEmployedTTM: number;
    netIncomePerEBTTTM: number;
    ebtPerEbitTTM: number;
    ebitPerRevenueTTM: number;
    debtRatioTTM: number;
    debtEquityRatioTTM: number;
    longTermDebtToCapitalizationTTM: number;
    totalDebtToCapitalizationTTM: number;
    interestCoverageTTM: number;
    cashFlowToDebtRatioTTM: number;
    companyEquityMultiplierTTM: number;
    receivablesTurnoverTTM: number;
    payablesTurnoverTTM: number;
    inventoryTurnoverTTM: number;
    fixedAssetTurnoverTTM: number;
    assetTurnoverTTM: number;
    operatingCashFlowPerShareTTM: number;
    freeCashFlowPerShareTTM: number;
    cashPerShareTTM: number;
    operatingCashFlowSalesRatioTTM: number;
    freeCashFlowOperatingCashFlowRatioTTM: number;
    cashFlowCoverageRatiosTTM: number;
    shortTermCoverageRatiosTTM: number;
    capitalExpenditureCoverageRatioTTM: number;
    dividendPaidAndCapexCoverageRatioTTM: number;
    priceBookValueRatioTTM: number;
    priceToBookRatioTTM: number;
    priceToSalesRatioTTM: number;
    priceEarningsRatioTTM: number;
    priceToFreeCashFlowsRatioTTM: number;
    priceToOperatingCashFlowsRatioTTM: number;
    priceCashFlowRatioTTM: number;
    priceEarningsToGrowthRatioTTM: number;
    priceSalesRatioTTM: number;
    dividendYieldTTM: number;
    enterpriseValueMultipleTTM: number;
    priceFairValueTTM: number;
}
export interface ICompanyInfo extends I_Id, IHasPolitiscales, IVal<IExchangeInfo>, IType {
    exchange: string;
    industry: string;
    minmov: number;
    minmov2: number;
    pricescale: number;
    profile: ICompanyProfile;
    sector: string;
    createdby: string;
    updatedby: string;
}
export interface ICompanyScales extends I_Id, IName, Required<IHasPolitiscales>, ITicker, IType {
    description: string;
    sector: string;
    industry: string;
    exchange: string;
    exchangeShortName: string;
    website: string;
    ceo: string;
    imageUrl: string;
    fullTimeEmployees: number;
    ipoDate: string;
}
export interface ICompanyProfile extends ISymbolPrice {
    beta: number;
    volAvg: number;
    mktCap: number;
    lastDiv: string;
    range: string;
    changes: number;
    companyName: string;
    currency: string;
    isin: string;
    isEtf: boolean;
    cusip: string;
    exchange: string;
    exchangeShortName: string;
    industry: string;
    website: string;
    description: string;
    ceo: string;
    sector: string;
    country: string;
    fullTimeEmployees: number;
    phone: string;
    address: string;
    city: string;
    state: string;
    zip: string;
    dcfDiff: string;
    dcf: string;
    image: string;
    ipoDate: string;
}
export interface IGainerLoser extends ISymbolPrice, ISymbolName {
    change: number;
    changesPercentage: number;
}
export interface IIpoCalendar extends ISymbol, IDate {
    company: string;
    exchange: string;
    actions: string;
    shares: number;
    priceRange: string;
    marketCap: number;
}
export interface IPlotPricesWithMidpoint extends ISymbol {
    startPrice: number;
    startDate: number;
    endPrice: number;
    endDate: number;
    midprice: number;
    requestDate: number;
}
export interface IPriceBar<Tdate = string> extends IDate<Tdate>, IVolume {
    open: number;
    high: number;
    low: number;
    close: number;
}
export interface IPriceBarSymbol<Tdate = string> extends IPriceBar<Tdate>, ISymbol {
}
export interface IPriceBarTicker<Tdate = string> extends IPriceBar<Tdate>, ITicker {
}
export interface IPriceHistory<Tdate = string> extends IPriceBar<Tdate> {
}
export interface IPriceHistoricalFull extends IPriceHistory {
    adjClose: number;
    unadjustedVolume: number;
    change: number;
    changePercent: number;
    vwap: number;
    label: string;
    changeOverTime: number;
}
export interface IPriceHistoryWithDateTime extends IPriceHistory {
    datetime: number;
}
export interface ISpac extends ISymbolName {
    ipoDate: string;
    marketCap: string;
    mergerPending: string;
    leverageFactor: number;
    momentumFactor10: number;
    momentumFactor200: number;
    lastClosePrice: number;
    sharesOutstanding: string;
    averageTradingVolume: string;
    percentTraded: string;
    action: string;
}
export interface ISymbolPrices extends ISymbol {
    candles: IPriceHistoryWithDateTime[];
    midprice: number;
    requestDate: number;
}
export declare class AssetQuoteShort implements ISymbolPriceVolume {
    symbol: string;
    price: number;
    volume: number;
    constructor(obj: any);
}
export declare class CompanyProfile implements ICompanyProfile {
    symbol: string;
    price: number;
    beta: number;
    volAvg: number;
    mktCap: number;
    lastDiv: string;
    range: string;
    changes: number;
    companyName: string;
    currency: string;
    isin: string;
    isEtf: boolean;
    cusip: string;
    exchange: string;
    exchangeShortName: string;
    industry: string;
    website: string;
    description: string;
    ceo: string;
    sector: string;
    country: string;
    fullTimeEmployees: number;
    phone: string;
    address: string;
    city: string;
    state: string;
    zip: string;
    dcfDiff: string;
    dcf: string;
    image: string;
    ipoDate: string;
}
export declare class ExchangeInfo implements IExchangeInfo {
    symbol: string;
    name: string;
    price: number;
    volume: number;
    exchange: string;
    exchangeShortName: string;
}
export interface IMarketHolidays {
    year: number;
    "New Years Day": string;
    "Martin Luther King, Jr. Day": string;
    "Washington's Birthday": string;
    "Good Friday": string;
    "Memorial Day": string;
    "Juneteenth National Independence Day": string;
    "Independence Day": string;
    "Labor Day": string;
    "Thanksgiving Day": string;
    "Christmas": string;
}
export interface IMarketOpenCloseHours {
    openingHour: string;
    closingHour: string;
}
export interface IMarketHours {
    stockExchangeName: string;
    stockMarketHours: IMarketOpenCloseHours;
    stockMarketHolidays: IMarketHolidays[];
    isTheStockMarketOpen: boolean;
    isTheEuronextMarketOpen: boolean;
    isTheForexMarketOpen: boolean;
    isTheCryptoMarketOpen: boolean;
}
export declare class PriceHistoricalResponse implements IPriceHistoricalFull {
    date: string;
    open: number;
    high: number;
    low: number;
    close: number;
    adjClose: number;
    volume: number;
    unadjustedVolume: number;
    change: number;
    changePercent: number;
    vwap: number;
    label: string;
    changeOverTime: number;
    datetime: number;
    constructor(obj: any);
}
export declare const CONST_defaultCompanyCity: ICompanyCity;
export interface IRatioCashFlow {
    capitalExpenditureCoverageRatios: string;
    cashFlowCoverageRatios: string;
    cashPerShare: string;
    dividendPayoutRatio: string;
    dividendpaidAndCapexCoverageRatios: string;
    freeCashFlowOperatingCashFlowRatio: string;
    freeCashFlowPerShare: string;
    operatingCashFlowPerShare: string;
    operatingCashFlowSalesRatio: string;
    payoutRatio: string;
    receivablesTurnover: string;
    shortTermCoverageRatios: string;
}
export interface IRatioDebt {
    cashFlowToDebtRatio: string;
    companyEquityMultiplier: string;
    debtEquityRatio: string;
    debtRatio: string;
    interestCoverage: string;
    longtermDebtToCapitalization: string;
    totalDebtToCapitalization: string;
}
export interface IRatioInvestmentValuation {
    dividendYield: string;
    enterpriseValueMultiple: string;
    priceBookValueRatio: string;
    priceCashFlowRatio: string;
    priceEarningsRatio: string;
    priceEarningsToGrowthRatio: string;
    priceFairValue: string;
    priceSalesRatio: string;
    priceToBookRatio: string;
    priceToFreeCashFlowsRatio: string;
    priceToOperatingCashFlowsRatio: string;
    priceToSalesRatio: string;
    receivablesTurnover: string;
}
export interface IRatioLiquidity {
    cashConversionCycle: string;
    cashRatio: string;
    currentRatio: string;
    daysOfInventoryOutstanding: string;
    daysOfPayablesOutstanding: string;
    daysOfSalesOutstanding: string;
    operatingCycle: string;
    quickRatio: string;
}
export interface IRatioOperatingPerformance {
    assetTurnover: string;
    fixedAssetTurnover: string;
    inventoryTurnover: string;
    payablesTurnover: string;
    receivablesTurnover: string;
}
export interface IRatioProfitability {
    eBITperRevenue: string;
    eBTperEBIT: string;
    effectiveTaxRate: string;
    grossProfitMargin: string;
    nIperEBT: string;
    netProfitMargin: string;
    operatingProfitMargin: string;
    pretaxProfitMargin: string;
    returnOnAssets: string;
    returnOnCapitalEmployed: string;
    returnOnEquity: string;
}
export interface IRatio extends ISymbol, IDate {
    period: string;
    currentRatio: number;
    quickRatio: number;
    cashRatio: number;
    daysOfSalesOutstanding: number;
    daysOfInventoryOutstanding: number;
    operatingCycle: number;
    daysOfPayablesOutstanding: number;
    cashConversionCycle: number;
    grossProfitMargin: number;
    operatingProfitMargin: number;
    pretaxProfitMargin: number;
    netProfitMargin: number;
    effectiveTaxRate: number;
    returnOnAssets: number;
    returnOnEquity: number;
    returnOnCapitalEmployed: number;
    netIncomePerEBT: number;
    ebtPerEbit: number;
    ebitPerRevenue: number;
    debtRatio: number;
    debtEquityRatio: number;
    longTermDebtToCapitalization: number;
    totalDebtToCapitalization: number;
    interestCoverage: number;
    cashFlowToDebtRatio: number;
    companyEquityMultiplier: number;
    receivablesTurnover: number;
    payablesTurnover: number;
    inventoryTurnover: number;
    fixedAssetTurnover: number;
    assetTurnover: number;
    operatingCashFlowPerShare: number;
    freeCashFlowPerShare: number;
    cashPerShare: number;
    payoutRatio: number;
    operatingCashFlowSalesRatio: number;
    freeCashFlowOperatingCashFlowRatio: number;
    cashFlowCoverageRatios: number;
    shortTermCoverageRatios: number;
    capitalExpenditureCoverageRatio: number;
    dividendPaidAndCapexCoverageRatio: number;
    dividendPayoutRatio: number;
    priceBookValueRatio: number;
    priceToBookRatio: number;
    priceToSalesRatio: number;
    priceEarningsRatio: number;
    priceToFreeCashFlowsRatio: number;
    priceToOperatingCashFlowsRatio: number;
    priceCashFlowRatio: number;
    priceEarningsToGrowthRatio: number;
    priceSalesRatio: number;
    dividendYield: number;
    enterpriseValueMultiple: number;
    priceFairValue: number;
}
export interface IFinancialRatios extends IDate {
    cashFlowIndicatorRatios: IRatioCashFlow;
    debtRatios: IRatioDebt;
    investmentValuationRatios: IRatioInvestmentValuation;
    liquidityMeasurementRatios: IRatioLiquidity;
    operatingPerformanceRatios: IRatioOperatingPerformance;
    profitabilityIndicatorRatios: IRatioProfitability;
}
export interface IFinancialRatiosResponse extends ISymbol {
    ratios: IFinancialRatios[];
}
export interface ISectorChangePercentage {
    sector: string;
    changesPercentage: string;
}
export interface ISectorsHistorical extends IDate {
    utilitiesChangesPercentage: number;
    basicMaterialsChangesPercentage: number;
    communicationServicesChangesPercentage: number;
    conglomeratesChangesPercentage: number;
    consumerCyclicalChangesPercentage: number;
    consumerDefensiveChangesPercentage: number;
    energyChangesPercentage: number;
    financialChangesPercentage: number;
    financialServicesChangesPercentage: number;
    healthcareChangesPercentage: number;
    industrialsChangesPercentage: number;
    realEstateChangesPercentage: number;
    servicesChangesPercentage: number;
    technologyChangesPercentage: number;
}
export interface ITickerSearch extends ISymbolName, ITicker, IType {
    full_name: string;
    description: string;
    exchange: string;
}
export interface ITickerSearchWithScales extends ITickerSearch, IHasPolitiscales {
}
export interface ITickerType extends IdName, ITicker, IType {
}
